@@ -29,7 +29,7 @@
 #
 #========================================================================
 #
-# Version 2.1.1, released 13 Mar 2005.
+# Version 2.1.2, released 5 Sep 2005.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -461,7 +461,8 @@ EOF
 		    $Lang->{Last_bad_XferLOG_errors_only},
 		    " class=\"navbar\"");
 	}
-	if ( -f "$TopDir/pc/$host/config.pl" ) {
+        if ( -f "$TopDir/pc/$host/config.pl"
+                    || ($host ne "config" && -f "$TopDir/conf/$host.pl") ) {
 	    NavLink("?action=view&type=config&host=${EscURI($host)}",
 		    $Lang->{Config_file}, " class=\"navbar\"");
 	}
