@@ -17,7 +17,7 @@ $Lang{Type_incr} = "incrmentielle";
 
 # -----
 
-$Lang{Only_privileged_users_can_view_admin_options} = "Seulement les usagers ayant les privilges appropris peuvent voir les options d'administration.";
+$Lang{Only_privileged_users_can_view_admin_options} = "Seuls les utilisateurs privilgis peuvent voir les options d'administration.";
 $Lang{H_Admin_Options} = "BackupPC: Options d'administration";
 $Lang{Admin_Options} = "Options d'administration";
 $Lang{Admin_Options_Page} = <<EOF;
@@ -39,7 +39,7 @@ $Lang{Admin_Options_Page} = <<EOF;
 -->
 EOF
 $Lang{Unable_to_connect_to_BackupPC_server} = "Impossible de se connecter au serveur BackupPC",
-            "Ce script CGI (\$MyURL) est incapable de se connecter au serverur BackupPC"
+            "Ce script CGI (\$MyURL) est incapable de se connecter au serveur BackupPC"
           . " sur \$Conf{ServerHost} au port \$Conf{ServerPort}.  L'erreur"
           . " est: \$err."
           . " Il est possible que le serveur BackupPC ne roule pas ou qu'il y a une erreur "
@@ -142,7 +142,7 @@ Il y a \$hostCntGood htes ayant t sauvegards, pour un total de :
     <td align="center"> Nb compltes </td>
     <td align="center"> Compltes ge/Jours </td>
     <td align="center"> Compltes Taille/Go </td>
-    <td align="center"> Vitesse Mo/sec </td>
+    <td align="center"> Vitesse Mo/s </td>
     <td align="center"> Nb incrmentielles </td>
     <td align="center"> Incrmentielles ge/Jours </td>
     <td align="center"> tat actuel </td>
@@ -160,7 +160,7 @@ Il y a \$hostCntNone htes sans sauvegardes.
     <td align="center"> Nb compltes </td>
     <td align="center"> Compltes ge/jour </td>
     <td align="center"> Compltes Taille/Go </td>
-    <td align="center"> Vitesse Mo/sec </td>
+    <td align="center"> Vitesse Mo/s </td>
     <td align="center"> Nb incrmentielles </td>
     <td align="center"> Incrmentielles ge/jours </td>
     <td align="center"> tat actuel </td>
@@ -207,7 +207,7 @@ Il y a \$hostCntGood htes qui ont ts sauvegards reprsentant \${fullSizeTot} Go
 <input type="hidden" name="action" value="Archive">
 <table class="tableStnd" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td align=center> Host</td>
-    <td align="center"> Usager </td>
+    <td align="center"> Utilisateur </td>
     <td align="center"> Taille </td>
 \$strGood
 \$checkAllHosts
@@ -273,7 +273,7 @@ EOF
 # -----------------------------------
 $Lang{Pool_Stat} = <<EOF;
         <li>La mise en commun est constitue de \$info->{"\${name}FileCnt"} fichiers
-            et \$info->{"\${name}DirCnt"} repertoires reprsentant \${poolSize} Go (depuis le \$poolTime),
+            et \$info->{"\${name}DirCnt"} rpertoires reprsentant \${poolSize} Go (depuis le \$poolTime),
         <li>Le hachage de mise en commun des fichiers donne \$info->{"\${name}FileCntRep"} fichiers rpts
             avec comme plus longue chane \$info->{"\${name}FileRepMax"},
         <li>Le nettoyage nocturne a effac \$info->{"\${name}FileCntRm"} fichiers, soit
@@ -286,7 +286,7 @@ $Lang{BackupPC__Backup_Requested_on__host} = "BackupPC: Sauvegarde demande sur \
 $Lang{REPLY_FROM_SERVER} = <<EOF;
 \${h1(\$str)}
 <p>
-La rponse du serveur a t: \$reply
+La rponse du serveur a t : \$reply
 <p>
 Retourner  la page d\'accueil de <a href="\$MyURL?host=\$host">\$host</a>.
 EOF
@@ -332,7 +332,7 @@ EOF
 # --------------------------------
 $Lang{Only_privileged_users_can_view_queues_} = "Seuls les utilisateurs privilgis peuvent voir les files.";
 # --------------------------------
-$Lang{Only_privileged_users_can_archive} = "(ENSLIGH) Only privileged users can Archive.";
+$Lang{Only_privileged_users_can_archive} = "Seuls les utilisateurs privilgis peuvent archiver.";
 # --------------------------------
 $Lang{BackupPC__Queue_Summary} = "BackupPC: Rsum de la file";
 # --------------------------------
@@ -406,7 +406,7 @@ EOF
 
 # -------------------------------
 $Lang{Recent_Email_Summary} = <<EOF;
-\${h1("Rsum des courriels rcents (Du plus rcent au plus vieux)")}
+\${h1("Rsum des courriels rcents (du plus rcent au plus vieux)")}
 <p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Destinataire </td>
@@ -426,13 +426,13 @@ $Lang{Restore_Options_for__host} = "BackupPC: Options de restauration sur \$host
 $Lang{Restore_Options_for__host2} = <<EOF;
 \${h1("Options de restauration sur \$host")}
 <p>
-Vous avez slectionn les fichiers/repertoires suivants depuis
+Vous avez slectionn les fichiers/rpertoires suivants depuis
 le partage \$share, sauvegarde numro \$num:
 <ul>
 \$fileListStr
 </ul>
 </p><p>
-Vous avez trois choix pour restaurer ces fichiers/repertoires.
+Vous avez trois choix pour restaurer ces fichiers/rpertoires.
 Veuillez slectionner une des options suivantes.
 </p>
 \${h2("Option 1: Restauration directe")}
@@ -591,7 +591,7 @@ $Lang{Restore_Requested_on__hostDest} = "BackupPC: Restauration demande sur \$ho
 $Lang{Reply_from_server_was___reply} = <<EOF;
 \${h1(\$str)}
 <p>
-La rponse du serveur est: \$reply
+La rponse du serveur est : \$reply
 <p>
 Retourner  la page d\'accueil de <a href="\$MyURL?host=\$hostDest">\$hostDest </a>.
 EOF
@@ -599,7 +599,7 @@ EOF
 $Lang{BackupPC_Archive_Reply_from_server} = <<EOF;
 \${h1(\$str)}
 <p>
-La rponse du serveur est: \$reply
+La rponse du serveur est : \$reply
 EOF
 
 
@@ -632,7 +632,7 @@ Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sa
     <td align="center"> Type </td>
     <td align="center"> Fusionne </td> 
     <td align="center"> Date de dmarrage </td>
-    <td align="center"> Dure/mins </td>
+    <td align="center"> Dure/min </td>
     <td align="center"> ge/jours </td>
     <td align="center"> Chemin d\'accs de la sauvegarde sur le serveur </td>
 </tr>
@@ -662,7 +662,7 @@ Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sa
 <p>
 Les fichiers existants sont ceux qui sont dj sur le serveur; 
 Les nouveaux fichiers sont ceux qui ont t ajouts au serveur.
-Les fichiers vides et les erreurs de SMB ne sont pas comptabiliss parmis les nouveaux et les rutiliss.
+Les fichiers vides et les erreurs de SMB ne sont pas comptabiliss parmi les nouveaux et les rutiliss.
 </p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
@@ -675,7 +675,7 @@ Les fichiers vides et les erreurs de SMB ne sont pas comptabiliss parmis les nou
     <td align="center"> Type </td>
     <td align="center"> Nb de Fichiers </td>
     <td align="center"> Taille/Mo </td>
-    <td align="center"> Mo/sec </td>
+    <td align="center"> Mo/s </td>
     <td align="center"> Nb de Fichiers </td>
     <td align="center"> Taille/Mo </td>
     <td align="center"> Nb de Fichiers </td>
@@ -712,7 +712,7 @@ EOF
 
 $Lang{Host__host_Archive_Summary} = "BackupPC: Rsum de l'archivage pour l'hte \$host";
 $Lang{Host__host_Archive_Summary2} = <<EOF;
-\${h1("Host \$host Archive Summary")}
+\${h1("Rsum de l'archivage pour l\'hte \$host")}
 <p>
 \$warnStr
 <ul>
@@ -834,7 +834,7 @@ $Lang{DirHistory_fileLink} = "v";
 $Lang{DirHistory_for__host} = <<EOF;
 \${h1("Historique des sauvegardes de rpertoires pour \$host")}
 <p>
-Cette page montre chaque version des fichiers parmis toutes sauvegardes:
+Cette page montre chaque version des fichiers parmi toutes sauvegardes:
 <ul>
 <li> Cliquez sur un numro de sauvegarde pour revenir  la navigation de sauvegarde,
 <li> Cliquez sur un rpertoire (\$Lang->{DirHistory_dirLink}) pour naviguer
@@ -846,7 +846,7 @@ Cette page montre chaque version des fichiers parmis toutes sauvegardes:
 <li> Les fichiers qui ne sont pas prsents sur une sauvegarde en particulier 
      sont reprsents par une boite vide.
 <li> Les fichiers montrs avec la mme version peuvent avoir des attributs diffrents. 
-     Choissisez le numro de sauvegarde pour voir les attributs de fichiers.
+     Choisissez le numro de sauvegarde pour voir les attributs de fichiers.
 </ul>
 
 \${h2("Historique de \${EscHTML(\$dirDisplay)}")}
@@ -860,10 +860,10 @@ Cette page montre chaque version des fichiers parmis toutes sauvegardes:
 EOF
 
 # ------------------------------
-$Lang{Restore___num_details_for__host} = "BackupPC: Dtails de la restauration n \$num pour \$host"; 
+$Lang{Restore___num_details_for__host} = "BackupPC: Dtails de la restauration n\$num pour \$host"; 
 
 $Lang{Restore___num_details_for__host2} = <<EOF;
-\${h1("Dtails de la restauration n \$num pour \$host")} 
+\${h1("Dtails de la restauration n\$num pour \$host")} 
 <p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="90%">
 <tr><td class="tableheader"> Numro </td><td class="border"> \$Restores[\$i]{num} </td></tr>
@@ -880,7 +880,7 @@ $Lang{Restore___num_details_for__host2} = <<EOF;
 <tr><td class="tableheader"> Dure </td><td class="border"> \$duration min </td></tr>
 <tr><td class="tableheader"> Nombre de fichier </td><td class="border"> \$Restores[\$i]{nFiles} </td></tr>
 <tr><td class="tableheader"> Grosseur totale </td><td class="border"> \${MB} Mo </td></tr>
-<tr><td class="tableheader"> Taux de transfert </td><td class="border"> \$MBperSec Mo/sec </td></tr>
+<tr><td class="tableheader"> Taux de transfert </td><td class="border"> \$MBperSec Mo/s </td></tr>
 <tr><td class="tableheader"> Erreurs de TarCreate </td><td class="border"> \$Restores[\$i]{tarCreateErrs} </td></tr>
 <tr><td class="tableheader"> Erreurs de transfert </td><td class="border"> \$Restores[\$i]{xferErrs} </td></tr>
 <tr><td class="tableheader"> Journal de transfert </td><td class="border">
@@ -898,10 +898,10 @@ $Lang{Restore___num_details_for__host2} = <<EOF;
 EOF
 
 # ------------------------------
-$Lang{Archive___num_details_for__host} = "BackupPC: Dtails de l'archivage no. \$num pour \$host";
+$Lang{Archive___num_details_for__host} = "BackupPC: Dtails de l'archivage n\$num pour \$host";
 
 $Lang{Archive___num_details_for__host2 } = <<EOF;
-\${h1("Archive #\$num Details for \$host")}
+\${h1("Dtails de l'archivage n\$num pour \$host")}
 <p>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr><td class="tableheader"> Numro </td><td class="border"> \$Archives[\$i]{num} </td></tr>
@@ -970,11 +970,11 @@ $Lang{Empty_host_name} = "Nom d\'hte vide";
 $Lang{Unknown_host_or_user} = "\${EscHTML(\$host)}, hte ou utilisateur inconnu.";
 $Lang{Only_privileged_users_can_view_information_about} = "Seuls les utilisateurs privilgis peuvent accder aux "
                 . " informations sur l\'hte \${EscHTML(\$host)}." ;
-$Lang{Only_privileged_users_can_view_archive_information} = "Seuls les usagers ayant les privilges ncessaires peuvent voir les informations d'archivage.";
+$Lang{Only_privileged_users_can_view_archive_information} = "Seuls les utilisateurs privilgis peuvent voir les informations d'archivage.";
 $Lang{Only_privileged_users_can_view_restore_information} = "Seuls les utilisateurs privilgis peuvent restaurer des informations.";
 $Lang{Restore_number__num_for_host__does_not_exist} = "Restauration numro \$num de l\'hte \${EscHTML(\$host)} n\'existe pas";
 
-$Lang{Archive_number__num_for_host__does_not_exist} = "L'archive no \$num pour l'hte \${EscHTML(\$host)} n'existe pas.";
+$Lang{Archive_number__num_for_host__does_not_exist} = "L'archive n\$num pour l'hte \${EscHTML(\$host)} n'existe pas.";
 
 $Lang{Can_t_find_IP_address_for} = "Ne peut pas trouver d\'adresse IP pour \${EscHTML(\$host)}";
 $Lang{host_is_a_DHCP_host} = <<EOF;
@@ -995,7 +995,7 @@ $Lang{Backup_requested_on_DHCP__host} = "Demande de sauvegarde sur l\'hte \$host
 $Lang{Backup_requested_on__host_by__User} = "Sauvegarde demande sur \$host par \$User";
 $Lang{Backup_stopped_dequeued_on__host_by__User} = "Sauvegarde Arrte/dprogramme pour \$host par \$User";
 $Lang{Restore_requested_to_host__hostDest__backup___num} = "Restauration demande pour l\'hte \$hostDest, "
-             . "sauvegarde n \$num, par \$User depuis \$ENV{REMOTE_ADDR}";
+             . "sauvegarde n\$num, par \$User depuis \$ENV{REMOTE_ADDR}";
 $Lang{Archive_requested} = "Archivage demand par \$User de \$ENV{REMOTE_ADDR}";
 
 # -------------------------------------------------
@@ -1028,7 +1028,7 @@ $Lang{Errors}  = "Erreurs";
 
 # ------------
 $Lang{Last_email_sent_to__was_at___subject} = <<EOF;
-<li>Dernier email envoy  \${UserLink(\$user)} le \$mailTime, avait comme sujet "\$subj".
+<li>Dernier courriel envoy  \${UserLink(\$user)} le \$mailTime, avait comme sujet "\$subj".
 EOF
 # ------------
 $Lang{The_command_cmd_is_currently_running_for_started} = <<EOF;
@@ -1062,7 +1062,7 @@ EOF
 
 # ------
 $Lang{Pings_to_host_have_failed_StatusHost_deadCnt__consecutive_times} = <<EOF;
-<li>Les pings vers \$host ont chous \$StatusHost{deadCnt} fois conscutives.
+<li>Les pings vers \$host ont chou \$StatusHost{deadCnt} fois conscutives.
 EOF
 
 # -----
@@ -1137,7 +1137,7 @@ Cliquer sur le numro de restauration pour plus de dtails.
 <tr class="tableheader"><td align="center"> Sauvegarde n </td>
     <td align="center"> Rsultat </td>
     <td align="right"> Date de dpart</td>
-    <td align="right"> Dure/mins</td>
+    <td align="right"> Dure/min</td>
     <td align="right"> Nb fichiers </td>
     <td align="right"> Mo </td>
     <td align="right"> Nb errs tar </td>
@@ -1169,7 +1169,7 @@ $Lang{No} = "non";
 $Lang{Yes} = "oui";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">Le repertoire \${EscHTML(\$dirDisplay)} est vide
+<tr><td bgcolor="#ffffff">Le rpertoire \${EscHTML(\$dirDisplay)} est vide
 </td></tr>
 EOF
 
@@ -1189,8 +1189,8 @@ $Lang{and} = "et";
 $Lang{Status_idle} = "inactif";
 $Lang{Status_backup_starting} = "dbut de la sauvegarde";
 $Lang{Status_backup_in_progress} = "sauvegarde en cours";
-$Lang{Status_restore_starting} = "dbut de la restoration";
-$Lang{Status_restore_in_progress} = "restoration en cours";
+$Lang{Status_restore_starting} = "dbut de la restauration";
+$Lang{Status_restore_in_progress} = "restauration en cours";
 $Lang{Status_link_pending} = "en attente de l'dition de liens";
 $Lang{Status_link_running} = "dition de liens en cours";
 
@@ -1220,7 +1220,7 @@ $userName,
 
 Notre logiciel de copies de scurit n'a jamais russi 
 prendre de sauvegarde de votre ordinateur ($host). Les sauvegardes
-devraient normallement survenir lorsque votre ordinateur est connect
+devraient normalement survenir lorsque votre ordinateur est connect
 au rseau. Vous devriez contacter le support informatique si:
 
   - Votre ordinateur est rgulirement connect au rseau, ce qui
@@ -1235,7 +1235,7 @@ Autrement, veuillez vous assurer que votre ordinateur est connect
 au rseau lorsque ce sera possible.
 
 Merci de votre attention,
-BackupPC Genie
+BackupPC Gnie
 http://backuppc.sourceforge.net
 EOF
 
@@ -1250,7 +1250,7 @@ $userName,
 
 Aucune sauvegarde de votre ordinateur n'a t effectue depuis $days
 jours. $numBackups sauvegardes ont ts effectues du $firstTime
-jusqu'il y  $days jours. Les sauvegardes devraient normallement
+jusqu'il y  $days jours. Les sauvegardes devraient normalement
 survenir lorsque votre ordinateur est connect au rseau.
 
 Si votre ordinateur a t connect au rseau plus de quelques heures
@@ -1265,12 +1265,12 @@ les fichiers attachs) ne pourra tre restaur si une problme survient
 avec votre ordinateur.
 
 Merci de votre attention,
-BackupPC Genie
+BackupPC Gnie
 http://backuppc.sourceforge.net
 EOF
 
 # Old Outlook files
-$Lang{EMailOutlookBackupSubj} = "BackupPC: Les fichiers de Outlook sur \$host doivent tes sauvegards";
+$Lang{EMailOutlookBackupSubj} = "BackupPC: Les fichiers de Outlook sur \$host doivent tre sauvegards";
 $Lang{EMailOutlookBackupMesg} = <<'EOF';
 To: $user$domain
 cc:
@@ -1284,7 +1284,7 @@ calendriers. $numBackups sauvegardes ont ts effectues du $firstTime
 au $lastTime.  Par contre, Outlook bloque ses fichiers lorsqu'il est
 ouvert, ce qui empche de les sauvegarder.
 
-Il est recommend d'effectuer une sauvegarde de vos fichiers Outlook
+Il est recommand d'effectuer une sauvegarde de vos fichiers Outlook
 quand vous serez connect au rseau en quittant Outlook et tout autre
 application, et en visitant ce lien avec votre fureteur web:
 
@@ -1297,7 +1297,7 @@ fureteur avec de vrifier le bon fonctionnement de la sauvegarde. La
 sauvegarde devrait prendre quelques minutes  s'effectuer.
 
 Merci de votre attention,
-BackupPC Genie
+BackupPC Gnie
 http://backuppc.sourceforge.net
 EOF
 
